@@ -5,22 +5,23 @@ from tests.factory.scrapy import fake_response
 
 
 def test_response_to_data_bag():
-    data = response_to_data_bag(
-        fake_response(
-            url="https://demo.com/test",
-            body=json.dumps({"name": "Easybook 15"}),
-        )
-    )
+    data = response_to_data_bag(fake_response(body=json.dumps({"name": "Easybook 15"})))
 
     assert json.loads(data["main"]) == {"name": "Easybook 15"}
 
 
+def test_response_to_data_bag_with_to_json():
+    data = response_to_data_bag(
+        fake_response(body=json.dumps({"name": "Easybook 15"})),
+        to_json=True,
+    )
+
+    assert data["main"] == {"name": "Easybook 15"}
+
+
 def test_response_to_data_bag_with_cb_kwargs():
     data = response_to_data_bag(
-        fake_response(
-            url="https://demo.com/test",
-            body=json.dumps({"name": "Easybook 15"}),
-        ),
+        fake_response(body=json.dumps({"name": "Easybook 15"})),
         brand_info={"name": "EasyData"},
         empty_info=None,
     )
